"use strict";

this.name = "Elite Trader";
this.author = "Reval";
this.description = "A profitable Market trade scores toward Elite";
this.version = "1.11";

/*  Version 1.11
	
	This OXP takes no account of cargo contracts,
	special deals, scoops of drifting cargo in space, 
	or of gems or precious metals.
	
	1.8  adds free auto-dock for good Brothers
	1.9  makes total profit apply to the System as a whole
	1.10 brings in the G.E.T. Advisory interface
	1.11 tightens G.E.T. strictures re ship-killing
	     introduces the Vow of Good Brotherhood
	
*/

	
this.playerSoldCargo = function(commodity, units, price) {
	var sale = 0; var tp = ""; var tm = "";
	// selling preliminaries - update quantity and price
	if (this.$etLastPrice[commodity]>0) {
		sale = price * units;
		this.$etSoldUnits += units;
		this.$etSoldPrice += sale;
		// note the commodities sold
		this.$etCommodities += commodity+" ";
	}
	// this sale's profit & total profit
	if (this.$etLastPrice[commodity] > 0) {
		this.$etProfit = sale - this.$etLastBuy[commodity];
		this.$etTotProfit += this.$etProfit;
		// prepare trade messages
		tp="   ( "+formatCredits(this.$etTotProfit/10,true,true)+" )";
		tm="Trade ("+commodity+"): "+formatCredits(this.$etProfit/10,true,true);
		// max trade is calculated outside Market screen
	}
	// see if we made a profit 
	this.$etMadeProfit = ((this.$etProfit>0) && (this.$etLastPrice[commodity]>0));

	// conditions for scoring
	this.$etOKtoScore = ((units > 2) && (!this.$etDone) && (this.$etBoughtUnits>0) && (this.$etMadeProfit) && (!this.$etIsBellig) && (!this.$etBeenBellig) && (!this.$etIsScooper));
	
	// decrement the manifest by # of units and price
	if (this.$etLastPrice[commodity]>0) {
		this.$etBoughtUnits -= units;
		this.$etBoughtPrice -= this.$etLastPrice[commodity] * units;
	}
	// display ship's cargo and its purchase value
	if (price==this.$etLastPrice[commodity])
		player.consoleMessage("In hold: "+this.$etBoughtUnits+" pods ( "+formatCredits(((this.$etBoughtPrice)/10),true,true)+" )");

	// credit a "market killing" on first profitable sell
	if (this.$etOKtoScore) {
		player.score++;
		this.$etPoints++;
		this.$etHasScored = true;
		player.consoleMessage("You made a killing!"+tp);
		if (!this.$etMarketObserver) player.consoleMessage(tm);
		// for simplicity, only one score per station
		this.$etDone = true;
	// otherwise acknowledge a skillful trade if we're not just unloading
	} else if (this.$etMadeProfit && (price!=this.$etLastPrice[commodity]) && (this.$etStation!=this.$etLastStation)) {
		player.consoleMessage("Nice trade!"+tp);
		if (!this.$etMarketObserver) player.consoleMessage(tm);
	}
}
	

this.playerBoughtCargo = function (commodity, units, price) {
	// buying preliminaries - record quantity and price
	this.$etBoughtUnits += units;
	this.$etBoughtPrice += price * units;
	this.$etLastBuy[commodity] = price * units;
	this.$etLastPrice[commodity] = price;
	// display ship's cargo and its purchase value
	player.consoleMessage("In hold: "+this.$etBoughtUnits+" pods ( "+formatCredits(((this.$etBoughtPrice)/10),true,true)+" )");
}


this.guiScreenChanged = function(to, from) {
	// update G.E.T. Status on Manifest screen
	if (from == "GUI_SCREEN_MARKET") {
		this._etGetMaxTrade();
		this._etShowStatus();
	} else
	if (to == "GUI_SCREEN_MARKET") {
		// a G.E.T. presence on the market floor
		player.consoleMessage("The "+this.$etSystem+" Guild of Elite Traders", 5);
		// show hold-status on entering Market
		var pods = this._etPodCount();
		player.consoleMessage("In hold: "+pods+" pods ( "+formatCredits(((this.$etBoughtPrice)/10),true,true)+" )");
		// advise player to unload and re-buy cargo after game-load
		if ((pods>0) && (this.$etBoughtPrice<=0)) player.consoleMessage("Elite Trader: Please sell cargo and re-buy.",5); 
	} else
	if (to == "GUI_SCREEN_MANIFEST") {
		// show best trade status on Manifest screen
		this._etShowStatus();
		// G.E.T. presence on the Manifest screen
		player.consoleMessage("Under the aegis of the "+this.$etSystem+" G.E.T", 10);
	} else 
	if (to == "GUI_SCREEN_STATUS")
		if (!this.$etVowing) {
			if (this.$etIsWelcomed) {
				if (!this.$etMadeProfit)
					player.consoleMessage("We trust your stay at "+this.$etSystem+" proves profitable!", 10);
				else player.consoleMessage(this.$etSystem+" is your lucky star!", 10);
			} else {
				this._etSayWelcome();
				this.$etIsWelcomed = true;
			} 
		} else this.$etVowing = false;
}


this.shipDockedWithStation = function(station) {
	this.$etLastStation = this.$etStation;
	this.$etStation = station;
	this.$etLastSystem = this.$etSystem;
	// System's G.E.T. welcomes the commander on arrival
	this._etSayWelcome();
	// clear flags and sold-quantities on docking
	this.$etDone = false;
	this.$etMadeProfit = false;
	this.$etHasScored = false;
	this.$etSoldUnits = 0;
	this.$etSoldPrice = 0;
	this.$etProfit = 0;
	// total profit is reset at WP exit
	this.$etCommodities = "";
	// leave an identical ship at the shipyard
	// in case player wishes to reset its specs
	this._etCloneShip();
	if (!this.$etBeenBellig) {
		// prep G.E.T. Advsory interface
		this._etPrepAdvisory(station);
		// prep G.E.T. Max Trade Resetter
		this._etPrepResetter(station);
	} else this._etPrepVow(station);
}


this.shipWillDockWithStation = function(station) {
	// refuel a good Brother's ship gratis
	var f ="";
	if ((player.ship.fuel<7) && (!this.$etIsBellig) && (!this.$etBeenBellig)) {
		player.ship.fuel = 7;
		f = "refuelled and "; }
	// if the Brother's recent trades were satisfactory...
	if (this.$etHasScored) {
		// a personal welcome from the local Guild Master
		player.addMessageToArrivalReport("The "+this.$etSystem+" Guild of Elite Traders bids their Brother "+player.name+" a hearty welcome to their Guild Home and trusts this sojourn among us will be advantageous...");
		player.addMessageToArrivalReport("Trade well! May the GETTING exceed the Taking!");
		// service the Brother's ship if its condition is under par
		if ((player.ship.serviceLevel<100) || (f!="")) {
			player.ship.serviceLevel = 100;
			player.addMessageToArrivalReport("Our Brother mechanic now reports that your craft is "+f+"in good repair. Fair voyage when you leave us, and return soon!");
		}
		// incremental protective enhancements for the Brother's ship
		if (this.$etLastSpeed<this.$etLimitSpeed) {
			player.ship.maxSpeed++;
			// check
			var spd = player.ship.maxSpeed;
		}
		if (this.$etLastThrust<this.$etLimitThrust) {
			player.ship.maxThrust++;
		}
		if (this.$etLastShields<this.$etLimitShields) {
			player.ship.maxForwardShield++;
			player.ship.maxAftShield++;
		}
		if (this.$etLastEnergy<this.$etLimitEnergy) {
			player.ship.maxEnergy++;
		}
		if (this.$etLastRecharge<this.$etLimitRecharge) {
			player.ship.forwardShieldRechargeRate+=0.025;
			player.ship.aftShieldRechargeRate+=0.025;
		}
		if (this.$etLastERecharge<this.$etLimitERecharge) {
			player.ship.energyRechargeRate+=0.05;
		}
		player.addMessageToArrivalReport("Our G.E.T. Brother adept has used an ages-lost and arcane technique to increase the capacity of your shields and your ship's speed by a small factor, that your passages in and out of our system might be a little safer.");
		if (spd!=this.$etLastSpeed) player.addMessageToArrivalReport("Previous speed: "+this.$etLastSpeed+";  Revised speed: "+player.ship.maxSpeed);
		player.addMessageToArrivalReport("Previous energy: "+this.$etLastEnergy+";  Revised energy: "+player.ship.maxEnergy);
		player.addMessageToArrivalReport("Previous recharge: "+this.$etLastERecharge.toFixed(2)+";  Revised recharge: "+player.ship.energyRechargeRate.toFixed(2));
		// update last specs after report
		this.$etLastSpeed=player.ship.maxSpeed;
		this.$etLastThrust=player.ship.maxThrust;
		this.$etLastShields=player.ship.maxForwardShield;
		this.$etLastEnergy=player.ship.maxEnergy;
		this.$etLastRecharge=player.ship.forwardShieldRechargeRate;
		this.$etLastERecharge=player.ship.energyRechargeRate;
		// remove fast-docking equipment
		player.ship.removeEquipment("EQ_ET_AUTODOCK");
	}
}


this.shipWillLaunchFromStation = function(station) {
	// G.E.T. ensures the good Brother's record is always clean
	if ((!this.$etIsBellig) && (!this.$etBeenBellig)) {
		player.ship.bounty = 0;
		// enable fast docking
		this._installAutoDock();
	}
}


this.shipLaunchedFromStation = function(stationLaunchedFrom) {
	if (!this.$etBeenBellig)
		player.commsMessage("The "+this.$etSystem+" G.E.T. Aegis wishes you clear lanes and an uneventful passage. Return safe!", 6);
	// weapons offline is the G.E.T. approved setting
	//player.ship.weaponsOnline = false; // doesn't appear to be writable
}


this.playerStartedJumpCountdown = function(type, seconds) {
	if (!this.$etBeenBellig)
		player.commsMessage("Be careful out among the miscreants Brother!",6);
	if ((!this.$etIsBellig) && (!this.$etBeenBellig) && (!this.$etIsScooper) && (!player.ship.weaponsOnline)) player.ship.massLockable = false;
}


this.shipEnteredStationAegis = function(station) {
	if (!this.$etBeenBellig)
		player.commsMessage("The Galactic Guild of Elite Traders welcomes you to "+this.$etSystem+" Aegis! We are at your disposal in the shipyard. Trade well!", 6);
	player.ship.massLockable = true; // no slamming into station
}


this.shipKilledOther = function(whom, damageType) {
     // we discount tins of SPAM and rocks
	 if ((whom.name!="SPAM") && (whom.name!="Asteroid")) {
		// G.E.T. disapproval
		player.commsMessage(this.$etSystem+" G.E.T. notes their Brother's lapse...");
		this.$etKillCount++;
		this.$etIsBellig = (this.$etKillCount>0); // temporary
		// a single kill might be accidental, but 3? - unlikely!
		if (this.$etKillCount>2) { 
			this.$etBeenBellig = true; // permanent - a blot on the record
			this._etFloorSpecs(); // ship specs back to nominal
		}
	}
}


this.shipScoopedOther = function(whom) {
     // G.E.T. disapproval
	player.commsMessage(this.$etSystem+" G.E.T. notes their Brother's lapse...");
	this.$etIsScooper = true;
}


this.shipEnteredPlanetaryVicinity = function(planet) {
	player.commsMessage("Entering gravity of "+planet.name);
	// Weps will always masslock near planets
	if (player.ship.weaponsOnline) player.ship.massLockable = true; // no slamming into planet
}


this.shipExitedPlanetaryVicinity = function(planet) {
	player.commsMessage("Leaving gravity of "+planet.name);
	if ((!this.$etIsBellig) && (!this.$etBeenBellig) && (!this.$etIsScooper) && (!player.ship.weaponsOnline)) player.ship.massLockable = false;
}


this.shipExitedWitchspace = function() {
	this.$etSystem = System.systemNameForID(system.ID);
	this.$etIsWelcomed = false;
	if (this.$etKillCount>0) this.$etKillCount--;
	this.$etIsBellig = (this.$etKillCount>0);
	this.$etIsScooper = false;
	// total profit is for system
	this.$etTotProfit = 0;
	this._etGetMaxTrade();
	this._etShowStatus();
}


this.playerBoughtNewShip = function(ship, price) {
	// spec globals to ship's initial values
	this._etResetSpecs();
	this.$etShipChanged = true;
	this._etGetMaxTrade();
	this._etShowStatus();
}


this.playerWillSaveGame = function(message) {
	missionVariables.etSpeed = this.$etLastSpeed;
	missionVariables.etThrust = this.$etLastThrust;
	missionVariables.etEnergy = this.$etLastEnergy;
	missionVariables.etShields = this.$etLastShields;
	missionVariables.etRecharge = this.$etLastRecharge;
	missionVariables.etERecharge = this.$etLastERecharge;
	missionVariables.etPoints = this.$etPoints;
	missionVariables.etKills = this.$etKillCount;
	missionVariables.etMaxTrade = this.$etMaxTrade;
	missionVariables.etMinTrade = this.$etMinTrade;
	missionVariables.etMaxTSystem = this.$etMaxTSystem;
	missionVariables.etMaxTGoods = this.$etMaxTGoods;
	missionVariables.etMaxTShip = this.$etMaxTShip;
	missionVariables.etMaxTShipName = this.$etMaxTShipName;
	missionVariables.etMaxTShipTC = this.$etMaxTShipTC;
	// cannot save booleans as "false/true" - must convert
	if (this.$etBeenBellig) var bb=1; else var bb=0;
	missionVariables.etBeenBellig = bb;
}


this.startUpComplete = function () {
	this.$etSystem = System.systemNameForID(system.ID);
	this._etResetSpecs();
	// default is current ship
	this.$etMaxTShip = player.ship.shipClassName;
	this.$etMaxTShipName = player.ship.shipUniqueName;
	this.$etMaxTShipTC = player.ship.cargoSpaceCapacity;
	// Load saved globals, if present
	var spd = missionVariables.etSpeed;
	var thr = missionVariables.etThrust;
	var ene = missionVariables.etEnergy;
	var shi = missionVariables.etShields;
	var rec = missionVariables.etRecharge;
	var rece = missionVariables.etERecharge;
	
	if (spd>=this.$etInitialSpeed) this.$etLastSpeed = spd;
	if (thr>=this.$etInitialThrust) this.$etLastThrust = thr;
	if (ene>=this.$etInitialEnergy) this.$etLastEnergy = ene;
	if (shi>=this.$etInitialShields) this.$etLastShields = shi;
	if (rec>=this.$etInitialRecharge) this.$etLastRecharge = rec;
	if (rece>=this.$etInitialERecharge) this.$etLastERecharge = rece;
	
	if (spd>=this.$etInitialSpeed) player.ship.maxSpeed = spd;
	if (thr>=this.$etInitialThrust) player.ship.maxThrust = thr;
	if (ene>=this.$etInitialEnergy) player.ship.maxEnergy = ene;
	if (shi>=this.$etInitialShields) player.ship.maxForwardShield = shi;
	if (rec>=this.$etInitialRecharge) player.ship.forwardShieldRechargeRate = rec;
	if (rece>=this.$etInitialERecharge) player.ship.energyRechargeRate = rece;
	// load points here too
	var pts = missionVariables.etPoints; if (pts>0) this.$etPoints = pts;
	var kil = missionVariables.etKills; if (kil>0) this.$etKillCount = kil; 
	var maxt = missionVariables.etMaxTrade; this.$etMaxTrade = maxt;
	var mint = missionVariables.etMinTrade; this.$etMinTrade = mint;
	var maxts = missionVariables.etMaxTSystem; this.$etMaxTSystem = maxts;
	var maxtg = missionVariables.etMaxTGoods; this.$etMaxTGoods = maxtg;
	var maxts = missionVariables.etMaxTShip; if (maxts!="") this.$etMaxTShip = maxts;
	var maxtn = missionVariables.etMaxTShipName; if (maxtn!="") this.$etMaxTShipName = maxtn;
	var maxtt = missionVariables.etMaxTShipTC; if (maxtt!=0) this.$etMaxTShipTC = maxtt;
	// cannot load booleans as "true/false" - must convert
	if (missionVariables.etBeenBellig != null) {
		var bb=missionVariables.etBeenBellig;
		this.$etBeenBellig = (bb == 1);
		// floor ship specs if the Brother went bad
		if (this.$etBeenBellig) this._etFloorSpecs();
	}
	// loading globals complete.
	if (this._etHasFE()) log(this.name, "finds FE Ships present ("+player.ship.shipClassName+")");
	// dock ship
	this.shipDockedWithStation(player.ship.dockedStation);
	this._etSayWelcome();
	this._etGetMaxTrade();
	this._etShowStatus();
	if (!this.$etBeenBellig) {
		// prep G.E.T. Advisory interface
		this._etPrepAdvisory(player.ship.dockedStation);
		// prep G.E.T. Max Trade Resetter
		this._etPrepResetter(player.ship.dockedStation);
	} else this._etPrepVow(player.ship.dockedStation);
}


this.startUp = function() {
    log(this.name, "Initialising OXP " + this.name);
	log(this.name, "detects version " + oolite.versionString);
	// declare & initialize globals
	this.$etMarketObserver = false;
	if (worldScripts["market_observer3"]) 
		this.$etMarketObserver = true;
	this.$etDone = false;
	this.$etMadeProfit = false;
	this.$etOKtoScore = false;
	this.$etHasScored = false;
	this.$etIsWelcomed = false;
	this.$etShipChanged = false;
	this.$etIsExcellent = false; // points>??
	this.$etIsScooper = false;
	this.$etIsBellig = false; // temporary
	this.$etBeenBellig = false; // permanent
	this.$etKillCount = 0; // ship-kills
	this.$etPoints = 0; // G.E.T. Elite-points scored
	this.$etVowing = false; // controls post-vow message
	this.$etSoldUnits = 0;
	this.$etSoldPrice = 0;
	this.$etBoughtPrice = 0;
	this.$etBoughtUnits = 0;
	this.$etProfit = 0;
	this.$etTotProfit = 0;
	this.$etMaxTrade = 0;
	this.$etMinTrade = 1000000;
	this.$etSystem = "";
	this.$etLastSystem = "";
	this.$etNextSystem = "";
	this.$etCommodities = ""; // commodities sold
	this.$etMaxTSystem = ""; // best trade's systen
	this.$etMaxTGoods = ""; // best trade's commodity
	this.$etMaxTShip = ""; // best trade's ship class
	this.$etMaxTShipName = ""; // best trade's ship name
	this.$etMaxTShipTC = 0; // best trade's ship tonnage
	this.$etStation = new Object(); // ??
	this.$etLastStation = new Object(); // ??
	this.$etLastPrice = new Array();
	for (var c=0; c<20; c++) this.$etLastPrice[c]=0;
	this.$etLastBuy = new Array();
	for (c=0; c<20; c++) this.$etLastBuy[c]=0;
	
	this.$etInitialSpeed = 0;
	this.$etInitialThrust = 0;
	this.$etInitialEnergy = 0;
	this.$etInitialShields = 0;
	this.$etInitialRecharge = 0.0; // shields recharge
	this.$etInitialERecharge = 0.0; // energy recharge

	this.$etLastSpeed = 0;
	this.$etLastThrust = 0;
	this.$etLastEnergy = 0;
	this.$etLastShields = 0;
	this.$etLastRecharge = 0.0;
	this.$etLastERecharge = 0.0;
	
	// constants
	this.$etLimitSpeed = 512;
	this.$etLimitThrust = 100;
	this.$etLimitEnergy = 512;
	this.$etLimitShields = 512;
	this.$etLimitRecharge = 12.0; // shield-R should be half energy-R
	this.$etLimitERecharge = 24.0; 
	
}


// # of cargo pods in ship's hold
this._etPodCount = function() {
	var result = 0;
	for (var i=0; i<manifest.list.length; i++) {
		var q = manifest.list[i].quantity;
		if (q > 0) result+= q;
	}	
	return result;
}


// is FE Ships Player installed?
this._etHasFE = function() {
	var str = player.ship.shipClassName;
	var n = str.search(" FE");
	return (n>-1);
}


// leave an identical ship at the shipyard
// in case player wishes to reset its specs
this._etCloneShip = function() {
	if (oolite.versionString>"1.88") {
		var pr = player.ship.price * 0.75;
		system.mainStation.addShipToShipyard({ 
			short_description: "G.E.T. offers you this clone of your ship, to reset our augmented specs to nominal, should you desire a clean break.", 
			shipdata_key: player.ship.dataKey, 
			price: pr, 
			personality:0,
			extras:[""]
		});
	}
}


// calculate running max/min trades and commodities
this._etGetMaxTrade = function() {
	if (this.$etTotProfit>this.$etMaxTrade) {
		this.$etMaxTrade=this.$etTotProfit;
		this.$etMaxTSystem=this.$etSystem;		
		this.$etMaxTGoods=this.$etCommodities;		
		// the ship we maxed it in
		this.$etMaxTShip = player.ship.shipClassName;
		this.$etMaxTShipName = player.ship.shipUniqueName;
		this.$etMaxTShipTC = player.ship.cargoSpaceCapacity;
	}
	if (this.$etTotProfit<this.$etMinTrade) this.$etMinTrade=this.$etTotProfit;
}


// send best trade status and today's profit to Manifest
this._etShowStatus = function() { 
	var statusTrade = "Best trade: " + formatCredits(this.$etMaxTrade/10, true, true ) + " (" + this.$etMaxTSystem + " - "+this.$etMaxTGoods+")";
	var sn = this.$etMaxTShipName; 
	if ((sn=="") || (sn==null)) sn = ""; else sn=" '"+this.$etMaxTShipName+"'"; 
	var statusShip = "Ship: "+this.$etMaxTShip+sn+" ("+this.$etMaxTShipTC+" TC)";
	var tp = this.$etTotProfit/10;
	var profitTotal = "Profit here: "+formatCredits(tp,true,true);
	mission.setInstructions(["G.E.T. Status:",statusTrade+".",statusShip+".",profitTotal+"."], this.name);
}


// nullify ship enhancements, setting specs to nominal
this._etFloorSpecs = function() {
	this.$etLastSpeed = this.$etInitialSpeed;
	this.$etLastThrust = this.$etInitialThrust;
	this.$etLastShields = this.$etInitialShields;
	this.$etLastEnergy = this.$etInitialEnergy;
	this.$etLastRecharge = this.$etInitialRecharge;
	this.$etLastERecharge = this.$etInitialERecharge;

	player.ship.maxSpeed = this.$etInitialSpeed;
	player.ship.maxThrust = this.$etInitialThrust;
	player.ship.maxForwardShield = this.$etInitialShields;
	player.ship.maxAftShield = this.$etInitialShields;
	player.ship.maxEnergy = this.$etInitialEnergy;
	player.ship.forwardShieldRechargeRate = this.$etInitialRecharge;
	player.ship.aftShieldRechargeRate = this.$etInitialRecharge;
	player.ship.energyRechargeRate = this.$etInitialERecharge;
}


this._etResetSpecs = function() {
	this.$etLastSpeed = player.ship.maxSpeed;
	this.$etLastThrust = player.ship.maxThrust;
	this.$etLastShields = player.ship.maxForwardShield;
	this.$etLastEnergy = player.ship.maxEnergy;
	this.$etLastRecharge = player.ship.forwardShieldRechargeRate;
	this.$etLastERecharge = player.ship.energyRechargeRate;
	// note ship's initial specs (for later comparisons)
	this.$etInitialSpeed = player.ship.maxSpeed;
	this.$etInitialThrust = player.ship.maxThrust;
	this.$etInitialShields = player.ship.maxForwardShield;
	this.$etInitialEnergy = player.ship.maxEnergy;
	this.$etInitialRecharge = player.ship.forwardShieldRechargeRate;
	this.$etInitialERecharge = player.ship.energyRechargeRate;
}


this._installAutoDock = function() {
	var p = player.ship;
	// give the non-straying Brother free fast-docking capability
	if (!this.$etIsBellig) {
		if (p.equipmentStatus("EQ_DOCK_COMP") != "EQUIPMENT_OK") {
			p.awardEquipment("EQ_ET_AUTODOCK");
		}
	}
}


// create G.E.T. Max Trade Resetter on the F4 Interfaces screen
this._etPrepResetter = function(station) {
	station.setInterface("etResetter",{
	title: "G.E.T. Best Trade Resetter",
	category: "G.E.T.",
	summary: "Reset your Best Trade to the profit gained in this system.",
	callback: this._etShowResetter.bind(this)
	});	
}


this._etSayWelcome = function() {
	if (!this.$etBeenBellig)
		player.consoleMessage("The "+this.$etSystem+" Guild of Elite Traders welcomes you!", 5);
}


// Present the option to reset Max Trade to the profit made here
this._etShowResetter = function() {
	
	var parameters = new Object();
	
	parameters.title = "The "+this.$etSystem+" Guild of Elite Traders";
	
	parameters.message = "The "+this.$etSystem+" Guild of Elite Traders offers you the opportunity to reset your Best Trade, as displayed on your ship's Manifest screen, to the profit you have just gained here in our system - in this case "+formatCredits(this.$etTotProfit/10, true, true)+". \n\n ";

	parameters.message += "In fact you would honour us by doing so...";
	
	parameters.choicesKey = "etResetMaxTradeChoices";
	
	mission.runScreen(parameters, callback);	

	function callback(choice) {
		if (choice === "1_YES")  {
			this.$etMaxTrade=this.$etTotProfit;
			this.$etMaxTSystem=this.$etSystem;		
			this.$etMaxTGoods=this.$etCommodities;		
			// the ship we maxed it in
			this.$etMaxTShip = player.ship.shipClassName;
			this.$etMaxTShipName = player.ship.shipUniqueName;
			this.$etMaxTShipTC = player.ship.cargoSpaceCapacity;
			player.commsMessage("Maximum Trade reset. Please check the Manifest.");
			// update Manifest
			this._etShowStatus();
		}
	}
}


// create G.E.T. Master Advisory on the F4 Interfaces screen
this._etPrepAdvisory = function(station) {
	station.setInterface("etAdvisory",{
	title: "G.E.T. Master Advisory",
	category: "G.E.T.",
	summary: "Salutation and advice from the Master of the "+this.$etSystem+" Guild of Elite Traders",
	callback: this._etShowAdvisory.bind(this)
	});	
}


// Salutation and advice from the station Guild Master
this._etShowAdvisory = function() {
	
	var parameters = new Object();
	
	parameters.title = "The "+this.$etSystem+" Guild of Elite Traders";
	
	parameters.message = "The "+this.$etSystem+" Guild of Elite Traders bids their Brother "+player.name+" a hearty welcome to their Guild Home and trusts this sojourn among us will be advantageous... Trade well! May the GETTING exceed the Taking! \n\n";
	
	parameters.message += "To business, Brother... ";
	
	if (this.$etPoints<=10) {
		parameters.message += "You may note with an ironic smile that G.E.T. cares little whether Galcop deems your bought goods illegal... We have small truck with that legislative body. With us, your record is always clean, and all trades legitimate in our eyes.  \n\n"

		parameters.message += "Words of advice are never amiss, you'll agree? ";
		
		parameters.message += "One abiding Rule governs our Order: Trade well, refrain from combat, aid your Brother Trader, whoever and wherever he, she, or it may be. Above all, do not kill.";
	
		parameters.message += "Remember it, and advance in Grade, wealth, and skill. Ignore it, and risk our silence. Then only Penance will bring you back. \n\n";
	
		parameters.message += "Your craft has a 'weapons offline' switch: use it before witch-jump, and see stars and enemies fly by when you engage your J-drive. G.E.T. offers you fast, priority docking at all Stations. In the shipyards, our Master mechs and techs are unrivalled. Your ship will flourish! ";
	} 
	else if (!this.$etMarketObserver) 
		parameters.message += "As it forever has been, Market Observer and Market Inquirer by Brother Spara, adjuncts to your calling, are almost de rigueur. Do not exit a space-dock without these!  \n \n";

	
	parameters.choicesKey = "etAcknowlege";
	
	mission.runScreen(parameters, callback);	

	function callback(choice) {
		if (choice === "1_YES")  player.commsMessage("Luck in the Markets!");
	}
}


// Vow of Good Brotherhood
this._etPrepVow = function(station) {
	station.setInterface("etVow",{
	title: "G.E.T. Vow of Good Brotherhood",
	category: "G.E.T.",
	summary: "Make a Vow of Good Brotherhood to the Master of the "+this.$etSystem+" Guild of Elite Traders",
	callback: this._etShowVow.bind(this)
	});	
}


// Present the option to make a Vow of Good Brotherhood
this._etShowVow = function() {
	
	var parameters = new Object();
	
	parameters.title = "The "+this.$etSystem+" Guild of Elite Traders";
	
	parameters.message = "We observed with sadness your straying from the Path of Good Brotherhood. You have killed - not once, but multiple times. Yet we understand your urges and the weakness of the newly inducted. For this reason, the "+this.$etSystem+" Guild of Elite Traders offers you the opportunity to mend errant ways... \n\n ";
	
	parameters.message += "The Masters of the Guild are prepared to reinstate you as a full Brother and restore all privileges of the G.E.T., indeed to forget your infractions, provided you demonstrate self-discipline and, above all, mercy in your future conduct on the space-lanes.\n\n ";
	
	parameters.message += "Remember the Rule: Do not kill. It is our only Rule. We do not ask why you broke it, but do demand that you respect and live by it. \n\n ";
	
	parameters.message += "Commander "+player.name+", are you prepared now to renew your Vow of Good Brotherhood with the Guild? \n\n ";

	this.$etVowing = true;
	parameters.choicesKey = "etVowChoices";
	
	mission.runScreen(parameters, callback);	

	function callback(choice) {
		if (choice === "1_YES")  {
			// reinstate Brother's privileges
			this.$etIsBellig = false;
			this.$etBeenBellig = false;
			this.$etKillCount = 0;
			player.ship.bounty = 0;
			player.consoleMessage("Then all is forgiven and we welcome you back.",5);
		} else player.consoleMessage("Then our backs must remain turned. Fare well.",5);
	}
}

